///////////////////////////////////////////////////////////////////////////////
//
// R interface implementation for file resize
//
// Copyright (C) 2009 Daniel Adler <dadler@uni-goettingen.de>
//
// Permission to use, copy, modify, and distribute this software for any
// purpose with or without fee is hereby granted, provided that the above
// copyright notice and this permission notice appear in all copies.
//
// THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
// WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
// ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
// WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
// ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
// OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
//
///////////////////////////////////////////////////////////////////////////////

#include "r_file_resize.h"
#include <Rdefines.h>
#include "utk_file_resize.hpp"
using namespace utk;
SEXP r_file_resize(SEXP spath, SEXP size)
{
  int err;
  const char* path = CHAR(STRING_ELT(spath,0));
  fsize_t  newsize = (fsize_t) REAL(size)[0];
  err = utk::file_resize(path, newsize);
  return Rf_ScalarLogical( (err == 0) ? TRUE : FALSE);
}


